@@ -19,6 +19,7 @@ package org.apache.tomcat.util.net;
 import java.io.IOException;
 import java.io.InputStream;
 import java.net.URI;
+import java.security.DomainLoadStoreParameter;
 import java.security.Key;
 import java.security.KeyStore;
 import java.security.cert.CRL;
@@ -37,6 +38,7 @@ import java.security.cert.X509CertSelector;
 import java.security.cert.X509Certificate;
 import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.Date;
 import java.util.Enumeration;
 import java.util.List;
@@ -54,7 +56,6 @@ import javax.net.ssl.X509KeyManager;
 
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
-import org.apache.tomcat.util.compat.JreCompat;
 import org.apache.tomcat.util.file.ConfigFileLoader;
 import org.apache.tomcat.util.net.jsse.JSSEKeyManager;
 import org.apache.tomcat.util.net.jsse.PEMFile;
@@ -121,12 +122,18 @@ public abstract class SSLUtilBase implements SSLUtil {
         sslHostConfig.setTls13RenegotiationAvailable(isTls13RenegAuthAvailable());
 
         // Calculate the enabled ciphers
-        boolean warnOnSkip = !sslHostConfig.getCiphers().equals(SSLHostConfig.DEFAULT_TLS_CIPHERS);
-        List<String> configuredCiphers = sslHostConfig.getJsseCipherNames();
-        Set<String> implementedCiphers = getImplementedCiphers();
-        List<String> enabledCiphers =
-                getEnabled("ciphers", getLog(), warnOnSkip, configuredCiphers, implementedCiphers);
-        this.enabledCiphers = enabledCiphers.toArray(new String[0]);
+        if (sslHostConfig.getCiphers().startsWith("PROFILE=")) {
+            // OpenSSL profiles
+            // TODO: sslHostConfig can query that with Panama, but skip for now
+            this.enabledCiphers = new String[0];
+        } else {
+            boolean warnOnSkip = !sslHostConfig.getCiphers().equals(SSLHostConfig.DEFAULT_TLS_CIPHERS);
+            List<String> configuredCiphers = sslHostConfig.getJsseCipherNames();
+            Set<String> implementedCiphers = getImplementedCiphers();
+            List<String> enabledCiphers =
+                    getEnabled("ciphers", getLog(), warnOnSkip, configuredCiphers, implementedCiphers);
+            this.enabledCiphers = enabledCiphers.toArray(new String[0]);
+        }
     }
 
 
@@ -189,15 +196,15 @@ public abstract class SSLUtilBase implements SSLUtil {
                 ks = KeyStore.getInstance(type, provider);
             }
             if ("DKS".equalsIgnoreCase(type)) {
-                URI uri = ConfigFileLoader.getURI(path);
-                ks.load(JreCompat.getInstance().getDomainLoadStoreParameter(uri));
+                URI uri = ConfigFileLoader.getSource().getURI(path);
+                ks.load(new DomainLoadStoreParameter(uri, Collections.emptyMap()));
             } else {
                 // Some key store types (e.g. hardware) expect the InputStream
                 // to be null
                 if(!("PKCS11".equalsIgnoreCase(type) ||
                         path.isEmpty() ||
                         "NONE".equalsIgnoreCase(path))) {
-                    istream = ConfigFileLoader.getInputStream(path);
+                    istream = ConfigFileLoader.getSource().getResource(path).getInputStream();
                 }
 
                 // The digester cannot differentiate between null and "".
@@ -316,8 +323,7 @@ public abstract class SSLUtilBase implements SSLUtil {
                     keyPass);
             PEMFile certificateFile = new PEMFile(certificate.getCertificateFile());
 
-            Collection<Certificate> chain = new ArrayList<>();
-            chain.addAll(certificateFile.getCertificates());
+            Collection<Certificate> chain = new ArrayList<>(certificateFile.getCertificates());
             if (certificate.getCertificateChainFile() != null) {
                 PEMFile certificateChainFile = new PEMFile(certificate.getCertificateChainFile());
                 chain.addAll(certificateChainFile.getCertificates());
@@ -467,7 +473,7 @@ public abstract class SSLUtilBase implements SSLUtil {
                             String msg = sm.getString("sslUtilBase.trustedCertNotValid", alias,
                                     ((X509Certificate) cert).getSubjectX500Principal(), e.getMessage());
                             if (log.isDebugEnabled()) {
-                                log.warn(msg, e);
+                                log.debug(msg, e);
                             } else {
                                 log.warn(msg);
                             }
@@ -529,7 +535,7 @@ public abstract class SSLUtilBase implements SSLUtil {
         Collection<? extends CRL> crls = null;
         try {
             CertificateFactory cf = CertificateFactory.getInstance("X.509");
-            try (InputStream is = ConfigFileLoader.getInputStream(crlf)) {
+            try (InputStream is = ConfigFileLoader.getSource().getResource(crlf).getInputStream()) {
                 crls = cf.generateCRLs(is);
             }
         } catch(IOException | CRLException | CertificateException e) {
